<?php
/**************************************************************************
 * $Id: response.php 4289 2010-08-27 10:17:09Z renner $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/


/* libs */
require_once('lib/StudIPortResponseTools.lib.php');


function responseSetViewedState() {
	$res = array('success' => false);

	// response sanity check (only receiver may delete)
	if (! validateResponseAccess($_REQUEST['response_id'], $GLOBALS['user']->id, $res, RESPONSE_ROLE_RECEIVER)) {
		return $res;
	}

	// establish DB connection and sanitize input
	$db =& new DB_Seminar();
	$response_id_esc = mysql_real_escape_string(intval($_REQUEST['response_id']));

	// prepare new state
	$state = ($_REQUEST['viewed']) ? 'Y' : 'N';

	// set viewed-state to true ('Y')
	$db->query("UPDATE studiport_feedback_response SET viewed='".$state."' WHERE response_id='".$response_id_esc."'");
	// NOTE don't check result, as an unaltered state will return zero changed rows

	// we're done, so signal success and return
	$res['success'] = true;
	return $res;
}


function responseDelete() {
	$res = array('success' => false);

	// response sanity check (only receiver may delete)
	if (! validateResponseAccess($_REQUEST['response_id'], $GLOBALS['user']->id, $res, RESPONSE_ROLE_RECEIVER)) {
		return $res;
	}

	// establish DB connection and sanitize input
	$db =& new DB_Seminar();
	$response_id_esc = mysql_real_escape_string(intval($_REQUEST['response_id']));

	// get question id before deleting anything
	$db->query("SELECT question_id FROM studiport_feedback_response WHERE response_id='$response_id_esc'");
	$db->next_record();
	$question_id = $db->f('question_id');

	// all is well, so delete response
	$db->query("DELETE FROM studiport_feedback_response WHERE response_id='$response_id_esc'");
	if ($db->affected_rows() == 0) {
		setErrorMsg($res, "Feedback-Frage konnte nicht gelöscht werden");
		return $res;
	}

	// get updated list and return
	$res['htmlContent'] = utf8_encode(responseGetList($question_id, $GLOBALS['user']->id));
	$res['success'] = true;
	return $res;
}


/**
 * Creates an new response with default data and writes the
 * new data to
 */
function responseCreate() {
	$res = array('success' => false);
	$setClause = new MySQLSetClause();

	// get DB connection and sanitize input
	$db =& new DB_Seminar();

	// response sanity check (only sender may create)
	$question_id_esc = mysql_real_escape_string($_REQUEST['question_id']);
	$name_esc        = mysql_real_escape_string($_REQUEST['author']);
	$user_id_esc     = mysql_real_escape_string($GLOBALS['user']->id);
	
	if ($user_id_esc != 'nobody') {
		$db->query("SELECT question_id "
			. " FROM studiport_feedback_request "
			. " WHERE question_id='". $question_id_esc ."' "
			. "   AND user_id='". $user_id_esc ."'");
	} elseif (isset($_SESSION['StudIPortExtAcc']['access_code'])) {
		$access_code_esc = mysql_real_escape_string($_SESSION['StudIPortExtAcc']['access_code']);
		
		if ($name_esc == '') {
			setErrorMsg($res, "Bitte Namen eingeben!");
			return $res;
		}
		
		$db->query("SELECT question_id "
			. " FROM      studiport_feedback_question AS q "
			. " LEFT JOIN studiport_view              AS view USING(view_id) "
			. " WHERE     q.question_id='" . $question_id_esc . "' "
			. " AND       q.public='Y' "
			. " AND       view.public='Y' "
			. " AND       view.access_code='" . $access_code_esc . "' ");
	} else {
		setErrorMsg($res, "Nicht eingeloggt und kein externer Zugang!");
		return $res;
	}

	if ($db->num_rows() != 1) {
		setErrorMsg($res, "Keine Berechtigung zum Antworten auf diese Frage");
		return $res;
	}

	// now check, if question has not expired
	$db->query("SELECT IF(expires,expires<CURDATE(),FALSE) AS expired"
                . " FROM studiport_feedback_question "
                . " WHERE question_id='". $question_id_esc ."'");
	$db->next_record();
        if ($db->f('expired')) {
                setErrorMsg($res, "Diese Frage kann nicht mehr beantwortet werden");
                return $res;
        }

	// validate name of question
	// TODO use generic checking here
	$text = sanitizeInput($_REQUEST['text']);
	$len  = strlen($text);
	if ($len < 10) {  // FIXME hard coding
		setErrorMsg($res, "Antwort '$text' zu kurz");
		return $res;
	} else if ($len > 1000) {  // FIXME hard coding
		setErrorMsg($res, "Antwort zu lang");
		return $res;
	}

	// default values for fields
	$setClause->set('question_id', $_REQUEST['question_id']);
	$setClause->set('user_id',     $GLOBALS['user']->id == 'nobody' ? "NULL" : $GLOBALS['user']->id);
	$setClause->set('author',      $GLOBALS['user']->id == 'nobody' ? $name_esc : "NULL");
	$setClause->set('created',     "NOW()", false);
	$setClause->set('edited',      "NOW()", false);
	$setClause->set('text',        $text);
	$setClause->set('viewed',      "N");

	// actually insert data into DB and verify success
	$db->query("INSERT INTO studiport_feedback_response SET ". $setClause->get());
	if ($db->affected_rows() == 0) {
		setErrorMsg($res, "Antwort konnte nicht erstellt werden");
		return $res;
	}

	// then remove the request
	if ($GLOBALS['user']->id != 'nobody') {
		$db->query("DELETE FROM studiport_feedback_request "
			. " WHERE question_id='". $question_id_esc ."' "
			. "   AND user_id='". $user_id_esc ."'");

	// get entry just created
	// TODO better use "insert_id" 
	$db->query("SELECT"
		. "   r.response_id,"
		. "   r.question_id,"
		. "   r.text,"
		. "   DATE_FORMAT(r.created, '%d.%m.%Y %k:%i Uhr') AS created, "
		. "   DATE_FORMAT(r.edited,  '%d.%m.%Y %k:%i Uhr') AS edited "
		. " FROM studiport_feedback_response AS r"
		. " WHERE question_id='". $question_id_esc ."'"
		. "   AND user_id='". $user_id_esc ."'"
		. " ORDER BY r.created DESC"
		. " LIMIT 0,1");
	} else {
		// get entry just created
		// TODO better use "insert_id" 
		$db->query("SELECT"
			. "   r.response_id,"
			. "   r.question_id,"
			. "   r.author,"
			. "   r.text,"
			. "   DATE_FORMAT(r.created, '%d.%m.%Y') AS created, "
			. "   DATE_FORMAT(r.edited,  '%d.%m.%Y') AS edited "
			. " FROM studiport_feedback_response AS r"
			. " LEFT JOIN studiport_feedback_question AS q    USING(question_id)"
			. " LEFT JOIN studiport_view              AS view USING(view_id)"
			. " WHERE r.question_id='". $question_id_esc ."'"
			. "   AND q.public='Y'"
			. "   AND view.public='Y'"
			. "   AND view.access_code='". $access_code_esc ."'"
			. "   AND NOT r.author='NULL'"
			. " ORDER BY r.created DESC"
			. " LIMIT 0,1");
	}
	
	if ($db->num_rows() != 1) {
		setErrorMsg($res, "Die neue Antwort kann nicht angezeigt werden");
		return $res;
	}

	// create and return HTML content, so that the table/list can be updated
	$db->next_record();
	$res['htmlContent'] = utf8_encode(
		  '<li>'
		.   '<div class="descr">'
		.     '<div id="re_text_abbr_' . $db->f('response_id') .'" style="display:none;">'
		.       textAbbreviate($db->f('text'), RESPONSE_ABBR_LENGTH)
		.       ' &raquo;&nbsp;<a href="javascript:StudIPort.response.show('. $db->f('response_id') .');">mehr</a>'
		.     '</div>'
		.     '<div id="re_text_'. $db->f('response_id') .'">'
		.       $db->f('text')
		.       ' &laquo;&nbsp;<a href="javascript:StudIPort.response.hide('. $db->f('response_id') .');">weniger</a>'
		.     '</div>'
		.     '<div class="fbDate">Antwort vom ' . $db->f('created')
		.       (($db->f('edited') != $db->f('created')) ? (' | zuletzt ge&auml;ndert am '. $db->f('edited')) : '')
		.     '</div>'
		.   '</div>'
		. '</li>');
	$res['success'] = true;
	return $res;
}
?>
