/**************************************************************************
 * $Id: fakeUploadButton.js 4278 2010-08-26 08:55:11Z renner $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/


/** Class to handle multiple file uploads and replaces the standard upload input form element
  * by a single button that is fully customizable
  *
  * REQUIREMENTS:
  * - fakeUploadButton.js
  * - fakeUploadButton.css
  *
  *
  * HOWTO USE:
  *
  * <input type="button" id="buttonId" /> element is the button that is going to invoke
  *                                       the file selection popup window
  *
  * Registration of this button as a replacement for the standard file upload input form works as follows:
  * 1) Add    window.onload = function() {
  *               new FakeUploadButton('buttonId');
  *           }
  *    at the the beginning of the website or
  *
  * 2) add    new FakeUploadButton('buttonId');    after the registered button element
  *
  * The list of selected files will be displayed in    <ul id="buttonIdList"></ul>
  */

FakeUploadButton = function(buttonId)
{
	this.button        = $(buttonId);
	this.listContainer = $(buttonId + 'List');
	
	// check if button object exists
	if (this.button === null) {
		alert('FakeUploadButton::FakeUploadButton: Upload Button does not exist!');
		return;
	}
	
	// check if file list container (<ul></ul>) exists
	if (this.listContainer === null) {
		alert('FakeUploadButton::FakeUploadButton: File list container does not exist!');
		return;
	}
	
	// adds necessary CSS properties for proper layout of the button
	this.button.addClassName('fakeUploadButton');
	
	// wrap container around the button (to cut the unresizable file input element later
	this.container = this.button.wrap(new Element('div', {'class': 'fakeUpload'}));
	
	// set container dimensions to button dimensions
	this.container.setStyle({
		width : this.button.getWidth()  + 1 + 'px',
		height: this.button.getHeight() + 1 + 'px'
	});
	
	// add the first (transparent) file input element
	this.addInputElement();
}

FakeUploadButton.prototype.addInputElement = function()
{
	that = this;
	
	// add file input element
	newInput = new Element('input', {
		'type'    : 'file',
		'class'   : 'fakeUploadFile',
		'name'    : 'file[]',
		'multiple': '',
		'size'    : 1
	});
	
	// when the value changes a file has been selected
	newInput.observe('change', function() {
		that.addFile(this);
	});
	
	this.container.insert({'bottom': newInput});
}

FakeUploadButton.prototype.addFile = function(inputObj)
{
	// file has been selected => hide this file input element and
	// stop observing events
	inputObj.setStyle({display: 'none'});
	inputObj.stopObserving();
	
	alert(inputObj.getValue());
	
	that = this;
	
	// add entry in file list
	if (this.fileListContainer !== 'undefined') {
		newEntry  = new Element('li');
		newDelete = new Element('img', {'src': StudIPortImgUri + '/trash.png'});
		newDelete.observe('click', function() {
			that.removeFile(this, inputObj);
		});
		newEntry.insert({'bottom': newDelete});
		newEntry.insert({'bottom': inputObj.getValue()});
		this.listContainer.insert({'bottom': newEntry});
	}
	
	this.addInputElement();
}

FakeUploadButton.prototype.removeFile = function(listObj, inputObj)
{
	listObj.parentNode.remove();
	inputObj.remove();
}
