/**************************************************************************
 * $Id: file.js 4278 2010-08-26 08:55:11Z renner $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/


StudIPort.file =
{
	/** removes a file from matrix / file list
	 * @param compK_in
	 * @param expK_in
	 * @param fileK_in
	 * @param typeK_in
	 *
	 * TODO I think it would be nice to pass only the fileId, would that work?
	 *      replaces 'removeNoAssocFile', 'removeFilesFromList' too
	 */
	remove : function(compK_in, expK_in, fileK_in, typeK_in) {
		// prepare confirmation text
		question = "M%F6chten Sie die Datei wirklich l%F6schen?\nBeachten Sie, dass s%E4mtliche die Datei betreffenden Daten damit unwiederbringlich entfernt werden."

		// get confirmation	
		ask = confirm(unescape(question));
		if (ask)
		{
			StudIPort.ajax.request({cmd: 'matrixRemoveFile', compK: compK_in, expK: expK_in, fileK: fileK_in, typeK: typeK_in}, this.removeSuccess, null);
		}
	},
	
	removeSuccess : function(res,par)
	{
		StudIPort.upload.updateUsageStat(res.usage);
		StudIPort.cache.update(StudIPort.cache.buildIndex(par.compK, par.expK, par.typeK), res.htmlContentList);
		
		// then update list and create new Sortable
		if(res.num == 0)
			StudIPort.box.closeNow();
		else
			$("div_hoverBox").update(res.htmlContentList);
			
		$("div_" + par.compK + "_" + par.expK).update(res.htmlContentOverview);
	},
	
	//removeFromList : function(compK_in, expK_in, fileK_in, typeK_in)
	removeFromList : function(fileId)
	{
		// prepare confirmation text
		question = "M%F6chten Sie die Datei wirklich l%F6schen?\nBeachten Sie, dass s%E4mtliche die Datei betreffenden Daten damit unwiederbringlich entfernt werden."

		// get confirmation	
		ask = confirm(unescape(question));
		if (ask == true)
			StudIPort.ajax.request({cmd: 'fileListDelete', fileIds: fileId}, this.removeFromListSuccess, this.removeFromListFailure);
			//StudIPort.ajax.request({cmd: 'matrixRemoveFile', compK: compK_in, expK: expK_in, fileK: fileK_in, typeK: typeK_in}, this.removeFromListSuccess, this.removeFromListFailure);
	},
	
	removeFromListSuccess : function(res,par)
	{
		// FIXME update categories (tables) with (currently not existing)
		// update information, i.e., new lines/rows
		location.reload();
	},
	
	removeFromListFailure : function(res,par)
	{
		alert(res.errorMsg);
	},
	
	removeMultipleFromList : function(formId, optionalName)
	{
		// get form object
		var form = $(formId);
		var fileIds = [];
		
		if (form == null) {
			return;
		}
		
		if (typeof optionalName == 'undefined') {
			boxes = form.getInputs('checkbox'); // get all checkboxes of form
		} else {
			boxes = form.getInputs('checkbox', optionalName); // get all checkboxes of form
		}
		
		boxes.each(function(e) {
			if (e.checked) {
				fileIds.push(e.value);
			}
		});
		
		// abort, if no checkboxes have been selected
		if (fileIds.length == 0) {
			alert("Es wurde(n) keine Datei(en) ausgewaehlt");
			return;
		}
		
		// prepare confirmation text
		question = "M%F6chten Sie die Datei wirklich l%F6schen?\nBeachten Sie, dass s%E4mtliche die Datei betreffenden Daten damit unwiederbringlich entfernt werden."
		
		// get confirmation	
		ask = confirm(unescape(question));
		if (ask == true)
			StudIPort.ajax.request({cmd: 'fileListDelete', fileIds: fileIds.join(',')}, this.removeMultipleFromListSuccess, this.removeMultipleFromListFailure);
			//StudIPort.ajax.request({cmd: 'matrixRemoveFile', compK: compK_in, expK: expK_in, fileK: fileK_in, typeK: typeK_in}, this.removeFromListSuccess, this.removeFromListFailure);
		
	},
	
	removeMultipleFromListSuccess : function(res,par)
	{
		// FIXME update categories (tables) with (currently not existing)
		// update information, i.e., new lines/rows
		location.reload();
	},
	
	removeMultipleFromListFailure : function(res,par)
	{
		alert(res.errorMsg);
	},
	
	removeNoAssoc : function(fileId, typeId)
	{
		// prepare confirmation text
		question = "M%F6chten Sie die Datei wirklich l%F6schen?\nBeachten Sie, dass s%E4mtliche die Datei betreffenden Daten damit unwiederbringlich entfernt werden."

		// get confirmation	
		ask = confirm(unescape(question));
		if (ask == true)
		{
			new StudIPort.ajax.request({cmd: 'matrixRemoveFile', compK: 0, expK: 0, fileK: fileId, typeK: typeId}, this.removeNoAssocSuccess, this.removeNoAssocFailure);
		}
	},
	
	removeNoAssocSuccess : function(res,par)
	{
		StudIPort.upload.updateUsageStat(res.usage);
		$("file_" + par.fileK + "_" + par.typeK).remove();
	},
	
	removeNoAssocFailure : function(res,par)
	{
		alert(res.errorMsg);
	},
	
	/** releases a file from matrix / file list and adds it to 'no assoc'-list
	 * @param compK_in
	 * @param expK_in
	 * @param fileK_in
	 * @param typeK_in
	 *
	 * TODO I think it would be nice to pass only the fileId, would that work?
	 */
	release : function(compK_in, expK_in, fileK_in, typeK_in)
	{
		StudIPort.ajax.request({cmd: 'matrixReleaseFile', compK: compK_in, expK: expK_in, fileK: fileK_in,  typeK: typeK_in}, this.releaseSuccess, null);
	},
	
	releaseSuccess : function(res, par)
	{
					
		if (res.num == 0) {
			StudIPort.box.closeNow();
			StudIPort.cache.del(StudIPort.cache.buildIndex(par.compK, par.expK, par.typeK));
		} else {
			$("div_hoverBox").update(res.htmlContentList);
			StudIPort.cache.update(StudIPort.cache.buildIndex(par.compK, par.expK, par.typeK), res.htmlContentList);
		}
		
		$("div_" + par.compK + "_" + par.expK).update(res.htmlContentOverview);
		
		if (res.numNoAssoc != 0) $("files").update(res.htmlContentNoAssoc);
		else $("files").update("- keine -");
					
		Sortable.create("files", {constraint: "", overlap: "horizontal", ghosting:true});
	},
	
	alloc : function(compK_in, expK_in, fileK_in, typeK_in)
	{
		StudIPort.ajax.request({cmd: 'matrixAllocFile', compK: compK_in, expK: expK_in, fileK: fileK_in, typeK: typeK_in}, this.allocSuccess, null);
	},
	
	allocSuccess : function(res, par)
	{
		StudIPort.cache.del(StudIPort.cache.buildIndex(par.compK, par.expK, par.typeK));
		$("div_" + par.compK + "_" + par.expK).update(res.htmlContent);
		if (res.numNoAssoc != 0) {
			$("files").update(res.htmlContentNoAssoc);
			Sortable.create("files", {constraint: "", overlap: "horizontal", ghosting:true});
		}
	},
	
	/** opens a box with file infos
	 * @param fileId ID of file
	 * @param boxId  ID of box
	 * @param obj    current object
	 */
	showInfo : function(fileId, boxId, obj)
	{
		sessionID = StudIPort.box.open(boxId, obj, true);
		
		cacheIndex = StudIPort.cache.buildIndex(fileId, "info");
		
		if (StudIPort.cache.exists(cacheIndex) == false) {
			StudIPort.ajax.request({cmd: 'fileGetInfo', file_id: fileId}, this.showInfoSuccess, this.showInfoFailure);
		} else {
			StudIPort.box.insertContent(StudIPort.cache.get(cacheIndex), sessionID);
		}
	},
	
	showInfoSuccess : function(res, par)
	{
		// update box
		StudIPort.box.insertContent(res.htmlContent, res.session);
		
		StudIPort.cache.update(StudIPort.cache.buildIndex(par.file_id, "info"), res.htmlContent);
		// finally, issue warnings if there are any
		/*if (res.warnings != null) {
			StudIPort.msgBox.update(mb, res.warnings, StudIPort.msgBox.WARNING);
		} else {
			updateMsgBox(mb, "", StudIPort.msgBox.WAITING);
		}*/
	},
	
	showInfoFailure : function(res, par)
	{
		alert(res.errorMsg);
	},
	
	/** opens box showing all views (public or private) of current file
	 * @param fileId ID of current file
	 * @param boxId  ID of box
	 * @param obj    current obj
	 * @param private show private or public views (boolean)
	 */
	showViews : function(fileId, boxId, obj, private)
	{
		sessionID = StudIPort.box.open(boxId, obj, true);
		
		cacheIndex = StudIPort.cache.buildIndex(fileId, "views", private ? "private" : "public");
		
		if (StudIPort.cache.exists(cacheIndex) == false) {
			StudIPort.ajax.request({cmd: private ? "fileGetViews" : "fileGetPublicViews", file_id: fileId}, this.showViewsSuccess, this.showViewsFailure);
		} else {
			StudIPort.box.insertContent(StudIPort.cache.get(cacheIndex), sessionID);
		}
	},	
	
	showViewsSuccess : function(res, par)
	{
		// update box
		StudIPort.box.insertContent(res.htmlContent, res.session);
		
		StudIPort.cache.update(StudIPort.cache.buildIndex(par.file_id, "views", (par.cmd == "fileGetViews") ? "private" : "public"), res.htmlContent);
		// finally, issue warnings if there are any
		/*if (res.warnings != null) {
			updateMsgBox(mb, res.warnings, MSGBOX_WARNING);
		} else {
			updateMsgBox(mb, "", MSGBOX_WAITING);
		}*/
	},
	
	showViewsFailure : function(res, par)
	{
		alert(res.errorMsg);
	},
	
	
	/*******************************************************************
	 * TODO this is redundant (also found in view.js)
	 ******************************************************************/
	 
	/**
	 */
	saveViewsForm : function(fileId)
	{
		src = $('fileViewsForm');

		// serialize data
		ch      = $(src).getInputs('checkbox');
		viewIds = new Array();
		
		if (ch.length > 0) {
			viewIds = ch.map(function(item) {
				return $F(item);
			}).join(':');
		}

		StudIPort.msgBox.update('fileViewsFormMsgBox', "&Uuml;bermittle Daten ...", StudIPort.msgBox.WAITING);

		// send data via ajax request
		StudIPort.ajax.request({cmd: 'fileSaveViews', file_id: fileId, views: viewIds}, this.saveViewsFormSuccess, this.saveViewsFormFailure);
	},
	
	saveViewsFormSuccess : function(res, par)
	{
		if (res.warnings != null) {
			StudIPort.msgBox.update('fileViewsFormMsgBox', res.warnings, StudIPort.msgBox.WARNING, true);
		} else {
			StudIPort.msgBox.update('fileViewsFormMsgBox', 'Daten gespeichert', StudIPort.msgBox.OK, true);
		}
		
		// update list
		StudIPort.updateCheckboxes('fileViewsForm', res.viewList);
	},
	
	saveViewsFormFailure : function(res, par)
	{
		StudIPort.msgBox.update('fileViewsFormMsgBox', res.errorMsg, StudIPort.msgBox.ERROR, true);
		
		// update list
		StudIPort.updateCheckboxes('fileViewsForm', res.viewList);
	},
	
	/**
	 */
	reloadViewsForm : function(fileId)
	{
		StudIPort.msgBox.update('fileViewsFormMsgBox', 'Hole Daten ...', StudIPort.msgBox.WAITING);
		StudIPort.ajax.request({cmd: 'fileReloadViews', file_id: fileId}, this.reloadViewsFormSuccess, this.reloadViewsFormFailure);
	},
	
	reloadViewsFormSuccess : function(res, par)
	{
		// update list
		StudIPort.updateCheckboxes('fileViewsForm', res.viewList);		

		// update message box
		if (res.warnings == null) {
			StudIPort.msgBox.update('fileViewsFormMsgBox', 'Daten zur&uuml;ckgesetzt', StudIPort.msgBox.OK, true);
		} else {
			StudIPort.msgBox.update('fileViewsFormMsgBox', res.warnings, StudIPort.msgBox.WARNING, true);
		}
	},
	
	reloadViewsFormFailure : function(res, par)
	{
		StudIPort.msgBox.update('fileViewsFormMsgBox', res.errorMsg, StudIPort.msgBox.ERROR, true);
	},
	
	download : function(formId, optionalName)
	{
		var form = $(formId);
		var fileIds = [];
		
		if (form == null) {
			return;
		}
		
		if (typeof optionalName == 'undefined') {
			boxes = form.getInputs('checkbox'); // get all checkboxes of form
		} else {
			boxes = form.getInputs('checkbox', optionalName); // get all checkboxes of form
		}
		
		boxes.each(function(e) {
			if (e.checked) {
				fileIds.push(e.value);
			}
		});
		
		// abort, if no checkboxes have been selected
		if (fileIds.length == 0) {
			alert("Es wurde(n) keine Datei(en) ausgewaehlt.");
			return;
		}
		
		window.location.href = StudIPortUrl + 'StudIPortDownload.php?file_id=' + fileIds.join(",");
	}
};
