/**************************************************************************
 * $Id: matrix.js 4278 2010-08-26 08:55:11Z renner $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/


StudIPort.matrix =
{
	hoverDisable : false, // disable hover effect
	oldRowColor  : "",
	oldColColor  : "",
	tabs         : new Tabs('StudIPortMatrixListTab', 'StudIPortMatrixListCol'),

	hover : function(rowId, colId, cellId, highlight, even)
	{
		if (this.hoverDisable)
		{
			return;
		}

		cellClass = even ? "evenRow" : "oddRow";

		if (highlight)
		{
			cellClass += "Hover";
			this.oldRowColor = $(rowId).getStyle('background-color');
			this.oldColColor = $(colId).getStyle('background-color');
		}

		$(cellId).className = cellClass;

		if (highlight)
		{
			$(rowId).style.backgroundColor = $(cellId).getStyle('background-color');
			$(colId).style.backgroundColor = $(cellId).getStyle('background-color');
		}
		else
		{
			$(rowId).style.backgroundColor = this.oldRowColor;
			$(colId).style.backgroundColor = this.oldColColor;
		}
	},

	showHidePart : function(id, isRow, hide)
	{
		// ask for confirmation if hiding is requested
		if (hide)
		{
			question  = "M%F6chten Sie die ";
			question += isRow ? "Zeile" : "Spalte";
			question += " wirklich ausblenden?\nBeachten Sie, dass dann die Zuordnungen der enthaltenen Dateien ebenfalls aufgehoben werden.";

			// get confirmation
			ask = confirm(unescape(question));

			if (! ask){
				return;
			}
		}

		// convert to numeric (PHP caused trouble)
		isRow = isRow ? 1 : 0;
		hide  = hide  ? 1 : 0;

		StudIPort.ajax.request({cmd: 'matrixShowHidePart', partId: id, 'isRow': isRow, 'hide': hide}, this.showHidePartSuccess, null);
	},

	showHidePartSuccess : function(res, par)
	{
		location.reload();
	},

	openList : function(id, obj, compKey, expKey, typeKey)
	{
		if (this.hoverDisable) {
			return;
		}

		sessionID = StudIPort.box.open(id, obj, true);
		cacheIndex = StudIPort.cache.buildIndex(compKey, expKey, typeKey);
		
		if (StudIPort.cache.exists(cacheIndex)) {
			StudIPort.box.insertContent(StudIPort.cache.get(cacheIndex), sessionID);
			Sortable.create("files_a", {constraint: "", overlap: "horizontal", ghosting:false});
		} else {
			StudIPort.ajax.request({cmd: 'matrixGetCell', compK: compKey, expK: expKey, typeK: typeKey}, this.openListSuccess, null);
		}
	},

	openListSuccess : function(res, par)
	{
		// update box
		StudIPort.box.insertContent(res.htmlContent, res.session);
		
		// save html to cache
		StudIPort.cache.update(StudIPort.cache.buildIndex(par.compK, par.expK, par.typeK), res.htmlContent);
	},

	infoOpen : function(id, obj, title, descr)
	{
		if (this.hoverDisable) {
			return;
		}

		sessionID = StudIPort.box.open(id, obj, false);
		StudIPort.box.insertContent('<div class=\"boxHeader\">' + title + '</div><div class=\"boxContent\">' + descr + '</div>', sessionID);
	},

	commentGet : function(id, obj, compKey, expKey)
	{
		if (this.hoverDisable) {
			return;
		}
		
		sessionID = StudIPort.box.open(id, obj, false);
		
		// reset msg box
		StudIPort.msgBox.update('commentsFormMsgBox', '', StudIPort.msgBox.WAITING);

		cacheIndex_int = StudIPort.cache.buildIndex(compKey, expKey, 'comment_int');
		cacheIndex_ext = StudIPort.cache.buildIndex(compKey, expKey, 'comment_ext');
		
		if (StudIPort.cache.exists(cacheIndex_int) && StudIPort.cache.exists(cacheIndex_ext)) {
			$('val_comment_int').value = StudIPort.cache.get(cacheIndex_int);
			$('val_comment_ext').value = StudIPort.cache.get(cacheIndex_ext);
			$('val_exp').value = expKey;
			$('val_comp').value = compKey;
	
			// show form	
			$('commentFormDiv').style.display = "block";

			cacheIndex = StudIPort.cache.buildIndex(compKey, expKey, 'comment_tab');
			
			if (StudIPort.cache.exists(cacheIndex)) {
				this.tabs.show(StudIPort.cache.get(cacheIndex));
			} else {
				this.tabs.show(1);
			}
		} else {
			// hide form and show "loading"-message
			$('commentFormDiv').style.display = "none";
			StudIPort.msgBox.update('commentsFormMsgBox', 'L&auml;dt', StudIPort.msgBox.WAITING);
			StudIPort.ajax.request({cmd: 'matrixGetCellComment', 'compKey': compKey, 'expKey': expKey}, this.commentGetSuccess, null);
		}
	},

	commentGetSuccess: function(res, par)
	{
		if (StudIPort.box.sessionID == res.session) {
			StudIPort.msgBox.update('commentsFormMsgBox', '', StudIPort.msgBox.WAITING);
			$('val_comment_int').value = res.text_int;
			$('val_comment_ext').value = res.text_ext;
			$('val_exp').value = par.expKey;
			$('val_comp').value = par.compKey;
		
			// show form	
			$('commentFormDiv').style.display = "block";
		
			if (res.picture == "int") {  // only internal text
				this.tabs.show(0);
				StudIPort.cache.update(cacheIndex = StudIPort.cache.buildIndex(compKey, expKey, 'comment_tab'), 0);
			} else {
				this.tabs.show(1);
				// what the fuck is this??
				StudIPort.cache.update(cacheIndex = StudIPort.cache.buildIndex(compKey, expKey, 'comment_tab'), 1);
			}
		}
		
		StudIPort.cache.update(StudIPort.cache.buildIndex(par.compKey, par.expKey, 'comment_int'), res.text_int);
		StudIPort.cache.update(StudIPort.cache.buildIndex(par.compKey, par.expKey, 'comment_ext'), res.text_ext);
	},

	commentSave : function(compKey, expKey, text_int, text_ext)
	{
		StudIPort.ajax.request({cmd: 'matrixCommentSave', 'compKey': compKey, 'expKey': expKey, 'text_int': text_int, 'text_ext': text_ext}, this.commentSaveSuccess, null);
	},

	commentSaveSuccess : function(res, par)
	{
		if (StudIPort.box.sessionID == res.session) {
			$('val_comment_int').value = res.text_int;
			$('val_comment_ext').value = res.text_ext;
		
			// show form	
			$('commentFormDiv').style.display = "block";
		}
		
		$('img_' + par.compKey + '_' + par.expKey).src = StudIPortImgUri + "description-" + res.picture + ".png";	

		StudIPort.msgBox.update('commentsFormMsgBox', 'gespeichert', StudIPort.msgBox.OK);
		commentsBasics.changedObjects.clear();
		$('val_comment_int').className = commentsBasics.defaultClass;
		$('val_comment_ext').className = commentsBasics.defaultClass;
		
		StudIPort.cache.update(StudIPort.cache.buildIndex(par.compKey, par.expKey, 'comment_int'), res.text_int);
		StudIPort.cache.update(StudIPort.cache.buildIndex(par.compKey, par.expKey, 'comment_ext'), res.text_ext);
	}
};
