/**************************************************************************
 * $Id: view.js 4278 2010-08-26 08:55:11Z renner $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/


StudIPort.view =
{
	hideDelay : 250,
	hideTimer : null,

	/**
	 * deletes a view using AJAX
	 *
	 * @param viewId  identifier of the view (as in database)
	 */
	del : function(viewId)
	{
		question = "Diese Ansicht wirklich löschen?";
		ask      = confirm(question);
		
		StudIPort.ajax.request({cmd: 'viewDelete', view_id: viewId}, this.deleteSuccess, this.deleteFailure);
	},
	
	deleteSuccess : function(res, par)
	{
		location.reload();
	},
	
	deleteFailure : function(res, par)
	{
		// TODO more appropriate way of displaying error message required!
		alert(res.errorMsg);
	},
	
	/**
	 * creates a new view using AJAX
	 */
	create : function(viewName)
	{
		StudIPort.ajax.request({cmd: 'viewCreate', name: viewName}, this.createSuccess, this.createFailure);
	},
	
	createSuccess : function(res, par)
	{
		//alert(res.htmlContent);
		location.reload();
	},
	
	createFailure : function(res, par)
	{
		// TODO more appropriate way of displaying error message required!
		alert(res.errorMsg);
	},
	
	/**
	 * displays the access link in a separate window
	 *
	 * @param target      target to write to
	 * @param viewId      identifier of the view (as in database)
	 * @param accessCode  access code for the given view
	 * @param entryUrl    for the public access plugin
	 */
	showAccessLink : function(target, viewId, accessCode, entryUrl)
	{
		this.cancelHideAccessLink();
		target = $(target);
		
		if (target)
		{
			accessUrl = "view_id=" + viewId + "&amp;access_code=" + accessCode;
			
			if (entryUrl.indexOf("?") == -1)
			{
				accessUrl = entryUrl + "?" + accessUrl;
			}
			else
			{
				accessUrl = entryUrl + "&amp;" + accessUrl;
			}
			
			target.update('<div style="padding-bottom:5px;">Geben Sie den folgenden Link weiter, um den Zugang zu dieser Ansicht au&szlig;erhalb von Stud.IP zu erm&ouml;glichen:</div><a href="' + accessUrl + '" target="_blank">' + accessUrl + '</a>');
			target.show();
		}
	},
	
	/**
	 * starts a timer to close the access link box of a view
	 */
	hideAccessLinkTimed : function(target)
	{
		target = $(target);
		
		if (target)
		{
			// not sure, if setTimeout works with scope-variable 'view.' that way
			this.hideTimer = window.setTimeout("StudIPort.view.hideAccessLink('" + target.id + "')", this.hideDelay);
		}
	},
	
	hideAccessLink : function(target)
	{
		target = $(target);
		target.hide();
	},
	
	cancelHideAccessLink : function()
	{
		if (this.hideTimer)
		{
			window.clearTimeout(this.hideTimer);
			this.hideTimer = null;
		}
	},
	
	/**
	 * saves the access privileges of the provided view via an AJAX request
	 *
	 * @param viewId  identifier of the view (as in database)
	 */
	saveAccessForm : function(viewId)
	{
		// serialize data
		src      = 'userList_act';
		ch       = $(src).childElements();
		userIds  = new Array();
		
		if (ch.length > 0) {
			userIds = ch.map( function(item) { return item.id; } ).join(':');
		}

		StudIPort.msgBox.update('viewAccessFormMsgBox', "&Uuml;bermittle Daten ...", StudIPort.msgBox.WAITING);
	
		// send data via ajax request
		StudIPort.ajax.request({cmd: 'viewSaveAccess', view_id: viewId, access: userIds}, this.saveAccessFormSuccess, this.saveAccessFormFailure);
	},
	
	saveAccessFormSuccess : function(res, par)
	{
		if (res.warnings != null) {
			StudIPort.msgBox.update('viewAccessFormMsgBox', res.warnings, StudIPort.msgBox.WARNING, true);
		} else {
			StudIPort.msgBox.update('viewAccessFormMsgBox', 'Daten gespeichert', StudIPort.msgBox.OK, true);
		}
		
		// reset list content and recreate sortable
		if (res.htmlContent) { 
			$('userList_act').update(res.htmlContent);
			StudIPort.view.initUserAccessSortable();
		}
	},
	
	saveAccessFormFailure : function(res, par)
	{
		StudIPort.msgBox.update('viewAccessFormMsgBox', res.errorMsg, StudIPort.msgBox.ERROR, true);
		
		// reset list content and recreate sortable
		if (res.htmlContent) { 
			$('userList_act').update(res.htmlContent);
			StudIPort.view.initUserAccessSortable();
		}
	},
	
	/**
	 * reloads the current access privileges of the provided view via an AJAX request
	 *
	 * @param viewId  identifier of the view (as in database)
	 */
	reloadAccessForm : function(viewId)
	{
		StudIPort.msgBox.update('viewAccessFormMsgBox', 'Hole Daten ...', StudIPort.msgBox.WAITING);
		
		StudIPort.ajax.request({cmd: 'viewReloadAccess', view_id: viewId}, this.reloadAccessFormSuccess, this.reloadAccessFormFailure);
	},
	
	reloadAccessFormSuccess : function(res, par)
	{
		// reset list content and recreate sortable
		$('userList_act').update(res.htmlContent);
		StudIPort.view.initUserAccessSortable();
		
		// update message box
		if (res.warnings == null) {
			StudIPort.msgBox.update('viewAccessFormMsgBox', 'Daten zur&uuml;ckgesetzt', StudIPort.msgBox.OK, true);
		} else {
			StudIPort.msgBox.update('viewAccessFormMsgBox', res.warnings, StudIPort.msgBox.WARNING, true);
		}
	},
	
	reloadAccessFormFailure : function(res, par)
	{
		StudIPort.msgBox.update('viewAccessFormMsgBox', res.errorMsg, StudIPort.msgBox.ERROR, true);
	},
	
	/**
	 * makes users with access rights draggable (for waste bin)
	 */
	initUserAccessSortable : function()
	{
		// TODO check whether draggables must to destroyed at some time ... (reload?)
		ch = $("userList_act").childElements();
		for (i = 0; i < ch.length; ++i) {
			new Draggable(ch[i], {
				revert   : true,
				ghosting : true
			});
		}

		// does not work!
		/*
		Sortable.create("userAccess_act", {
			tag:         "div",
			//containment: "userAccess_sel",
			containment: false,
			constraint:  false,
			overlap:     "horizontal",
			ghosting:    true
			//hoverclass:  "userAddHover",
			//onUpdate:    viewAddUser,
			//dropOnEmpty: true,
		});
		*/
	},
	
	/**
	 * makes users from list of search results draggable to add them to the view's list
	 * of users with access rights
	 */
	initUserSelectSortable : function()
	{
		// TODO check whether draggables must to destroyed at some time ... (new search?)
		ch = $("userList_sel").childElements();
		
		for (i = 0; i < ch.length; ++i) {
			new Draggable(ch[i], {
				revert   : true,
				ghosting : true
			});
		}

		// does not work!
		/*
		Sortable.create("userAccess_sel", { 
			tag:         "div",
			containment: false,
			constraint:  false,
			overlap:     "horizontal",
			ghosting:    true
		});
		*/
	},
	
	/**
	 * adds a user from the list of searcj results to the list of users with access
	 * rights. Duplicates are deleted.
	 *
	 * @param el  the element that has been provided by the user for addition
	 */
	addUser : function(el)
	{
		// users from the selection list have ids with
		// a prepending "x:", so we simply search for
		// this string to obtain the user id
		uid = el.id.substring(el.id.indexOf(':') + 1);

		// remove element from selection list
		el.remove();

		// get destination
		dst = $("userList_act");

		// check, whether new element already exists
		ch = dst.childElements();
		
		for (i = 0; i < ch.length; ++i) {
			if (ch[i].id == uid) {
				return;
			}
		}

		// new element is not a duplicate, so insert into list
		StudIPort.msgBox.update($('viewAccessFormMsgBox'), "Zugriffsrechte ge&auml;ndert und ungespeichert", StudIPort.msgBox.CHANGED);
		el.id = uid;
		dst.insert(el);
	},
	
	/**
	 * remove item/user from list of users with access rights
	 *
	 * @param el  element that the user wants to delete from the list
	 */
	removeUser : function(el)
	{
		StudIPort.msgBox.update($('viewAccessFormMsgBox'), "Zugriffsrechte ge&auml;ndert und ungespeichert", StudIPort.msgBox.CHANGED);
		el.remove();
	},
	
	changedFilesForm : function(dummy)
	{
		StudIPort.msgBox.update($('viewFilesFormMsgBox'), "Dateiliste ge&auml;ndert und ungespeichert", StudIPort.msgBox.CHANGED);
	},
	
	/**
	 */
	saveFilesForm : function(viewId)
	{
		// serialize data
		src     = 'StudIPortFileListForm';
		ch      = $(src).getInputs('checkbox');
		fileIds = new Array();
		
		if (ch.length > 0) {
			fileIds = ch.map(function(item) {
				return $F(item);
			}).join(':');
		}

		StudIPort.msgBox.update('viewFilesFormMsgBox', "&Uuml;bermittle Daten ...", StudIPort.msgBox.WAITING);

		// send data via ajax request
		StudIPort.ajax.request({cmd: 'viewSaveFiles', view_id: viewId, files: fileIds}, this.saveFilesFormSuccess, this.saveFilesFormFailure);
	},
	
	saveFilesFormSuccess : function(res, par)
	{
		if (res.warnings != null) {
			StudIPort.msgBox.update('viewFilesFormMsgBox', res.warnings, StudIPort.msgBox.WARNING, true);
		} else {
			StudIPort.msgBox.update('viewFilesFormMsgBox', 'Daten gespeichert', StudIPort.msgBox.OK, true);
		}
		
		// update list
		StudIPort.updateCheckboxes('StudIPortFileListForm', res.fileList);
	},
	
	saveFilesFormFailure : function(res, par)
	{
		StudIPort.msgBox.update('viewFilesFormMsgBox', res.errorMsg, StudIPort.msgBox.ERROR, true);
		
		// update list
		StudIPort.updateCheckboxes('StudIPortFileListForm', res.fileList);
	},
	
	/**
	 */
	reloadFilesForm : function(viewId)
	{
		StudIPort.msgBox.update('viewFilesFormMsgBox', 'Hole Daten ...', StudIPort.msgBox.WAITING);
		StudIPort.ajax.request({cmd: 'viewReloadFiles', view_id: viewId}, this.reloadFilesFormSuccess, this.reloadFilesFormFailure);
	},
	
	reloadFilesFormSuccess : function(res, par)
	{
		// update list
		StudIPort.updateCheckboxes('StudIPortFileListForm', res.fileList);
		
		// update message box
		if (res.warnings == null) {
			StudIPort.msgBox.update('viewFilesFormMsgBox', 'Daten zur&uuml;ckgesetzt', StudIPort.msgBox.OK, true);
		} else {
			StudIPort.msgBox.update('viewFilesFormMsgBox', res.warnings, StudIPort.msgBox.WARNING, true);
		}
	},
	
	reloadFilesFormFailure : function(res, par)
	{
		StudIPort.msgBox.update('viewFilesFormMsgBox', res.errorMsg, StudIPort.msgBox.ERROR, true);
	},
	
        /** opens a box with view infos
	 * @param viewId ID of view
	 * @param boxId  ID of box
	 * @param obj    current object
	 */
	showInfo : function(viewId, boxId, obj)
	{
		StudIPort.box.open(boxId, obj, true);
		StudIPort.ajax.request({cmd: 'viewGetInfo', 'view_id': viewId}, this.showInfoSuccess, this.showInfoFailure);
	},

	showInfoSuccess : function(res, par)
	{
		// update box
		StudIPort.box.insertContent(res.htmlContent, res.session);
	},

	showInfoFailure : function(res, par)
	{
		alert(res.errorMsg);
	},

	/* toggle state of view (viewed / not viewed) */
	stateToggle : function(viewId)
	{
		state = $('view_state_' + viewId);
		if (state == null) {
			return;
		}

		viewedState = (state.src.indexOf("yes") == -1) ? 0 : 1;
		StudIPort.ajax.request({cmd: 'viewSetViewedState', view_id: viewId, viewed: viewedState}, this.stateToggleSuccess, this.stateToggleFailure);
	},

	stateToggleSuccess : function(res, par)
	{
		state = $('view_state_' + par.view_id);
		if (state == null) {
			return;
		}

		// indicate new state
		if (par.viewed != 0) {
			state.src = state.src.sub('yes', 'no');
		} else {
			state.src = state.src.sub('no', 'yes');
		}
	},

	stateToggleFailure : function(res, par)
        {
		/* silently ignore this at the moment */
	}
};
