<?php
/**************************************************************************
 * $Id: StudIPortBase.class.php 4289 2010-08-27 10:17:09Z renner $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/


require_once('StudIPortDB.class.php');
require_once('vendor/flexi/flexi.php');
require_once(dirname(__FILE__) . '/../config/StudIPort.config.php');

/** @class StudIPortBase
 * @brief abstract class for all StudIPort pages ..
 */
abstract class StudIPortBase
{
	protected $user;
	protected $template;
	// StudIPortDB object, created in StudIPortBase 
	// Use in all subclasses to avoid million times of creating StudIPortDB objects
	// perhaps saves memory
	// allows us to change the used "databaseclass" very easily
	protected $sql;

	/**
	 * @see http://de3.php.net/manual/de/language.oop5.typehinting.php, would be best to use it elsewhere too
	 * @note user now obligatory
	 *
	 * @param user StudIPUser who is requesting data
	 */
	public function __construct(StudIPUser &$user) {
		$this->user      = $user;
		$this->template  = NULL;
		$this->sql       =& new StudIPortDB();	// do this in __contruct because nearly every subclass needs it
	}

	/** loads data requiered to generate output
	 */
	abstract public function loadData();
	
	/** creates some output using templates
	 *
	 * @param factory Flexi_TemplateFactory which was initialized with path where templateFilename is found
	 * @param templateFilename string containing filename of template to use
	 * @param pluginUrl string containing url to plugin directory for use in templates to include files in html for example
	 */
	public function render(Flexi_TemplateFactory &$factory, $templateFilename, $pluginUrl) {
		$this->template = $factory->open($templateFilename);
		$this->template->set_attribute('url', $pluginUrl);
	}
}
?>
