<?php
/**************************************************************************
 * $Id: StudIPortFeedbackList.class.php 4278 2010-08-26 08:55:11Z renner $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/


require_once('StudIPortPart.class.php');
require_once('StudIPortTools.lib.php');

/** @class StudIPortFeedbackList
 */
class StudIPortFeedbackList extends StudIPortPart
{
	protected $viewId;
	protected $questions;
	protected $responses;
	protected $numRequests;

	public function __construct(StudIPUser &$user, $viewId = null) {
		parent::__construct($user);
		$this->viewId      = $viewId;
		$this->questions   = array();
		$this->responses   = array();
		$this->numRequests = 0;
	}
	
	/** loads files associated with matrix
	 * @see StudIPortMatrixBase::loadData()
	 * @param void
	 */
	public function loadData() {
		// if a view is specified, get files of that view for the checkboxes
		if (empty($this->viewId)) {
			// ERROR
			return;
		}
		
		$sql =& $this->sql;
	
		// get questions associated with this view, which have a pending request or a reply from current user
		// TODO tell, if a question's edited date is younger than the latest reply of the user
		$sql->queryf(
			  " SELECT DISTINCT"
			. "   question_id," 
			. "   text,"
//			. "   DATE_FORMAT(created, '%%d.%%m.%%Y %%k:%%i Uhr') AS created, "
//			. "   DATE_FORMAT(edited,  '%%d.%%m.%%Y %%k:%%i Uhr') AS edited, "
//			. "   DATE_FORMAT(expires, '%%e. %%b %%Y') AS expires, "
			. "   DATE_FORMAT(created, '%%d.%%m.%%Y') AS created, "
			. "   DATE_FORMAT(edited,  '%%d.%%m.%%Y') AS edited, "
			. "   IF(expires,DATE_FORMAT(expires, '%%d.%%m.%%Y'),FALSE) AS expires, "
			. "   IF(expires,expires<CURDATE(),FALSE) AS expired, "
			. "   (SELECT IF(COUNT(*)>0,TRUE,FALSE) FROM studiport_feedback_request WHERE question_id=q.question_id AND user_id='%s') AS requestPending"
			. " FROM studiport_feedback_question AS q"
			. " WHERE view_id='%d'"
			. "   AND question_id IN ("
			. "     SELECT question_id FROM studiport_feedback_request WHERE user_id='%s'"
			. "       UNION DISTINCT"
			. "     SELECT question_id FROM studiport_feedback_response WHERE user_id='%s'"
			. " )"
			. " ORDER by q.edited DESC",
			$this->user->getUserId(),
			$this->viewId, $this->user->getUserId(), $this->user->getUserId());

		while ($sql->next_record()) {
			$sql->Record['text_abbr'] = textAbbreviate($sql->f('text'), QUESTION_ABBR_LENGTH);
			array_push($this->questions, $sql->Record);
			// prepare list of responses
			$this->responses[$sql->f('question_id')] = array();
			if (! $sql->f('expired') && $sql->f('requestPending')) {
				$this->numRequests++;
			}
		}

		// get user's replies to this view's questions
		$sql->queryf(
			  " SELECT"
			. "   response_id,"
			. "   question_id,"
			. "   r.author,"
			. "   r.text,"
//			. "   DATE_FORMAT(r.created, '%%d.%%m.%%Y %%k:%%i Uhr') AS created, "
//			. "   DATE_FORMAT(r.edited,  '%%d.%%m.%%Y %%k:%%i Uhr') AS edited, "
			. "   DATE_FORMAT(r.created, '%%d.%%m.%%Y') AS created, "
			. "   DATE_FORMAT(r.edited,  '%%d.%%m.%%Y') AS edited, "
			. "   r.viewed"
			. " FROM studiport_feedback_response AS r"
			. "   LEFT JOIN studiport_feedback_question USING(question_id)"
			. " WHERE view_id='%d'"
			. "   AND user_id='%s'"
			. " ORDER by r.edited DESC",
			$this->viewId, $this->user->getUserId());

		while ($sql->next_record()) {
			$sql->Record['text_abbr'] = textAbbreviate($sql->f('text'), RESPONSE_ABBR_LENGTH);
			array_push($this->responses[$sql->f('question_id')], $sql->Record);
		}
	}

	public function getNumRequests() {
		return $this->numRequests;
	}

	public function render(Flexi_TemplateFactory &$factory, $templateFilename, $pluginUrl) {
			parent::render($factory, $templateFilename, $pluginUrl);
			$this->template->set_attribute('viewId',    $this->viewId);
			$this->template->set_attribute('questions', $this->questions);
			$this->template->set_attribute('responses', $this->responses);
			$this->template->set_attribute('isExtern',  false);
			return $this->template->render();
	}
}
?>
