<?php
/**************************************************************************
 * $Id: StudIPortFileListExtAcc.class.php 4278 2010-08-26 08:55:11Z renner $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/


require_once('StudIPortFileList.class.php');

/** @class StudIPortFileListOwner
 */
class StudIPortFileListExtAcc extends StudIPortFileList
{
	protected $viewId;
	protected $ownerId;

	public function __construct(StudIPUser &$user, $viewId) {
		parent::__construct($user);
		$this->rights = STUDIPORT_RIGHTS_ALIEN;
		$this->checkCallback = ''; 
		$this->viewId = $viewId;
		
		$this->sql->queryf("SELECT user_id FROM studiport_view WHERE view_id = '%s'", $this->viewId);
		if ($this->sql->num_rows() == 0) {
			// TODO error message
			return;
		}
		
		$this->sql->next_record();
		$this->ownerId = $this->sql->f('user_id');
	}
	
	protected function getCellDescr() {
		// get cell descriptions
		$sql =& $this->sql;
		$sql->queryf("SELECT comp_id, exp_id, text_ext FROM studiport_matrix_cell_descr WHERE user_id='%s'", $this->ownerId);
		while ($sql->next_record()) {
			$key = $sql->f('exp_id') . ':' . $sql->f('comp_id');
			//$this->cellDescr[$key] = $sql->f('text_ext'); 
			$this->cellDescr[$key] = textConvertNewline($sql->f('text_ext'));
		}
	}
	
	/** loads files associated with matrix
	 * @see StudIPortMatrixBase::loadData()
	 * @param void
	 */
	public function loadData() {
		
		if (empty($this->viewId)) {
			// TODO error message
			return;
		}
		
		parent::loadData();
		
		$sql =& $this->sql;
		
		// get files of view
		$sql->queryf("SELECT file_id, title, comp_id, exp_id, type_id,
					 UNIX_TIMESTAMP(edited) as edited, descr_ext
					 FROM studiport_file file
					 LEFT JOIN studiport_file_assoc USING (file_id)
					 LEFT JOIN studiport_view_files USING (file_id)
					 WHERE file_id IN
					 (SELECT file_id FROM studiport_view_files WHERE view_id='%s')
					 ORDER BY comp_id, exp_id, title", $this->viewId);

		parent::prepareData($sql);

		// convert text to html
		if ($this->data) {
			foreach ($this->data as &$row) {
				foreach ($row as &$col) {
					foreach ($col as &$file) {
						$file['descr_ext'] = textConvertNewline($file['descr_ext'], FILE_DESCR_ABBR_LENGTH);
					}
				}
			}
		}
	}
	
	/** @see StudIPortFiles::getHeaderData() */
	/*protected function getHeaderData() {
		$sql =& $this->sql;
		
		// get competence/rows headers
		$sql->queryf("SELECT comp_id as id, title, descr FROM `studiport_matrix_comp`
					 WHERE comp_id NOT IN
					 (SELECT comp_id FROM studiport_matrix_comp_hide WHERE user_id = '%s')
					 ORDER BY pos ASC", $this->ownerId);

		$this->comp = NULL;
		$this->saveSqlData($sql, $this->comp);

		// get experience/cols headers
		$sql->queryf("SELECT exp_id as id, title, descr FROM `studiport_matrix_exp`
					 WHERE exp_id NOT IN
					 (SELECT exp_id FROM studiport_matrix_exp_hide WHERE user_id = '%s')
					 ORDER BY pos ASC", $this->ownerId);
		
		$this->exp  = NULL;
		 $this->saveSqlData($sql, $this->exp);
	}*/
	
	public function render(Flexi_TemplateFactory &$factory, $templateFilename, $pluginUrl) {
		parent::render($factory, $templateFilename, $pluginUrl);

		$this->template->set_attribute('isExtern', true);

		return $this->template->render();
	}
}
?>
