<?php
/**************************************************************************
 * $Id: StudIPortFileListOwner.class.php 4278 2010-08-26 08:55:11Z renner $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/


require_once('StudIPortFileList.class.php');

/** @class StudIPortFileListOwner
 */
class StudIPortFileListOwner extends StudIPortFileList
{
	protected $viewId;

	public function __construct(StudIPUser &$user, $viewId = null) {
		parent::__construct($user);
		$this->viewId = $viewId;
		$this->rights = STUDIPORT_RIGHTS_OWNER;
		$this->checkCallback = $viewId ? 'StudIPort.view.changedFilesForm' : '';
	}
	
	/** loads files associated with matrix
	 * @see StudIPortMatrixBase::loadData()
	 * @param void
	 */
	public function loadData() {
		parent::loadData();
		
		$sql =& $this->sql;
		
		$sql->queryf(
			'SELECT '.
			'  file_id, '.
			'  title, '.
			'  comp_id, '.
			'  exp_id, '.
			'  type_id, '.
			'  descr_int, '.
			'  SUBSTRING(descr_ext, 1, '. FILE_DESCR_ABBR_LENGTH .') AS descr_ext, '.
			'  UNIX_TIMESTAMP(edited) as edited, '.
			'  CHAR_LENGTH(file.descr_int) > 0 as hasText '.
			'FROM studiport_file file '.
			'  LEFT JOIN studiport_file_assoc USING (file_id) '.
			'WHERE file.user_id = \'%s\' '.
			'ORDER BY comp_id, exp_id, title',
			$this->user->getUserId());

		$this->prepareData($sql);
		$this->getNumViews();

		// abbreviate text of files
		if ($this->data) {
			foreach ($this->data as &$row) {
				foreach ($row as &$col) {
					foreach ($col as &$file) {
						$file['descr_ext'] = textConvertNewline(textAbbreviate($file['descr_ext'], FILE_DESCR_ABBR_LENGTH));
					}
				}
			}
		}

		// if a view is specified, get files of that view for the checkboxes
		if (!empty($this->viewId)) {
			$sql->queryf("SELECT file_id FROM studiport_view_files WHERE view_id='%s'", $this->viewId);
			
			while ($sql->next_record()) {
				$this->filesChecked[$sql->f('file_id')] = true;
			}
		}
	}
	
	private function getNumViews() {
		$sql =& $this->sql;
		
		// get number of views (public and private) per file
		$sql->queryf("SELECT COUNT(*) as num, file_id, public, comp_id, exp_id
								   FROM studiport_view_files
								   LEFT JOIN studiport_view USING (view_id)
								   LEFT JOIN studiport_file_assoc USING (file_id)
								   WHERE user_id = '%s' group by file_id, public", $this->user->getUserId());
		
		while ($sql->next_record()) {
			if ($sql->Record["comp_id"] != NULL) {
				$pointer =& $this->data[$sql->Record["comp_id"]][$sql->Record["exp_id"]][$sql->Record["file_id"]];
			} else {
				$pointer =& $this->dataNoAssoc[$sql->Record["file_id"]];
			}
			
			$pointer['num_views_all'] += $sql->Record["num"];
			
			if ($sql->Record["public"] == 'Y') {
				$pointer['num_views_ext'] = $sql->Record["num"];
			}
		}	
	}
}
?>
