<?php
/**************************************************************************
 * $Id: StudIPortResponseList.class.php 4278 2010-08-26 08:55:11Z renner $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/


require_once('StudIPortPart.class.php');
require_once('StudIPortTools.lib.php');

class StudIPortResponseList extends StudIPortPart
{
	protected $questionId;
	protected $users;
	protected $responses;
	protected $numNewAnswers;

	public function __construct(StudIPUser &$user, $questionId = null) {
		parent::__construct($user);
		$this->questionId    = $questionId;
		$this->users         = array();
		$this->responses     = array();
		$this->numNewAnswers = 0;
	}
	
	/** loads files associated with matrix
	 * @see StudIPortMatrixBase::loadData()
	 * @param void
	 */
	public function loadData() {
		// if a view is specified, get files of that view for the checkboxes
		if (empty($this->questionId)) {
			// ERROR
			return;
		}

		// now check if user has access to the corresponding question
		// TODO is this necessary?
		$res = array();
		if (! validateQuestionAccess($this->questionId, $this->user->getUserId(), $res, QUESTION_ROLE_OWNER)) {
			// ERROR
			return;
		}
		
		$sql =& $this->sql;

		// get responses
		$sql->queryf(
			'SELECT '.
			'  response_id, '.
			'  user_id, '.
			'  author, '.
			'  DATE_FORMAT(created, \'%%d.%%m.%%Y %%k:%%i Uhr\') AS created, '.
			'  DATE_FORMAT(edited,  \'%%d.%%m.%%Y %%k:%%i Uhr\') AS edited, '.
			'  text, '.
			'  viewed '.
			'FROM studiport_feedback_response '.
			'WHERE (question_id = \'%d\')'.
			'ORDER BY created DESC',
			$this->questionId);

		while ($sql->next_record()) {
			$sql->Record['text_preview'] = textAbbreviate($sql->Record['text'], RESPONSE_ABBR_LENGTH);
			array_push($this->responses, $sql->Record);
			if ($sql->f('viewed') != 'Y') {
				$this->numNewAnswers++;
			}
		}
	
		// get users associated with this view of this question
		global $_fullname_sql;
		$sql->queryf(
			'SELECT DISTINCT '.
			'  user_id, '.
			'  username, '.
			'  '.$_fullname_sql['no_title_rev'] .' AS fullname '.
			'FROM studiport_feedback_response '.
			'  LEFT JOIN auth_user_md5 USING(user_id) '.
			'WHERE question_id = \'%d\'',
			$this->questionId);

		while ($sql->next_record()) {
			$this->users[$sql->f('user_id')] = $sql->Record;
		}
	}

	public function getNumNew () {
		return $this->numNewAnswers;
	}

	public function getNum () {
		return count($this->responses);
	}

	public function render(Flexi_TemplateFactory &$factory, $templateFilename, $pluginUrl) {
		parent::render($factory, $templateFilename, $pluginUrl);
		$this->template->set_attribute('questionId', $this->questionId);
		$this->template->set_attribute('users',      $this->users);
		$this->template->set_attribute('responses',  $this->responses);
		return $this->template->render();
	}
}
?>
