<?php
/**************************************************************************
 * $Id: StudIPortViewList.class.php 4278 2010-08-26 08:55:11Z renner $
 *
 * Copyright (C) 2008, 2009, 2010; Hamburg University of Technology
 *
 * > TECHNICAL REALIZATION
 *   Christian Renner <christian.renner@tu-harburg.de>
 *   Leo Krueger
 *   Sigurd Spieckermann
 *
 * > CONCEPT
 *   Peter Baasch
 *   Detlev Bieler
 *   Thomas Czerwionka
 *   Thomas Hapke
 *   Soenke Knutzen
 *   Corinna Peters
 *   Christian Renner
 *   Volker Turau
 *   Olav Wilde
 *
 **************************************************************************
 * This file is part of "StudIPort 2.0 ePortfolio".
 *
 * "StudIPort 2.0 ePortfolio" is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * "StudIPort 2.0 ePortfolio" is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "StudIPort 2.0 ePortfolio".
 * If not, see <http://www.gnu.org/licenses/>.
 *
 *************************************************************************/

 
require_once('StudIPortPart.class.php');

class StudIPortViewList extends StudIPortPart
{
	// constants, filters for data loading
	const FILTER_ALL           = 0;
	const FILTER_EXPIRE        = 1;
	const FILTER_NEW_FEEDBACK  = 2;

	// member variables
	protected $views;      ///> holds the user's views queried from DB

	/**
	 * @see StudIPort::__construct
	 * @param user StudIP user object of calling user
	 */
	public function __construct(StudIPUser &$user) {
		parent::__construct($user);
		$this->views    = null;
	}

	/**
	 *  @user_id 
	 */
	public function loadData($filter = self::FILTER_ALL) {
		if (!empty($this->views) || empty($this->user)) {
			// TODO print error msg
			return;
		}

		// get DB connection and sanitized user id
		$res =& new DB_Seminar();
		$id_esc = mysql_real_escape_string($this->user->getUserId());

		// set up WHERE clause depending on the filter
		if ($filter === self::FILTER_NEW_FEEDBACK) {
			$res->queryf(
				'SELECT '.
				'  DISTINCT view_id '.
				'FROM studiport_feedback_response r'.
				'  LEFT JOIN studiport_feedback_question '.
				'    USING(question_id) '.
				'  LEFT JOIN studiport_view v'.
				'    USING(view_id) '.
				'WHERE v.user_id=\'%s\' AND viewed!=\'Y\' AND DATEDIFF(now(), r.created) BETWEEN 0 AND %d ', $this->user->getUserId(), STUDIPORT_DAYS_NEW);

			// any results?
			if ($res->num_rows() == 0) {
				$this->views    = array();
				return;
			}

			$r = array();
			while ($res->next_record()) {
				array_push($r, intval($res->Record['view_id']));
			}
			$whereCl = 'view_id IN ('. implode(",", $r) .')';
		} else if ($filter === self::FILTER_EXPIRE) {
			$whereCl = "user_id='$id_esc' AND expires AND DATEDIFF(expires, now()) BETWEEN 0 AND ". STUDIPORT_DAYS_NEW;
		} else {
			$whereCl = "user_id='$id_esc'";
		}

		// get all views belonging to user
		//$res->query("SELECT view_id, name, descr, IF(expires, DATE_FORMAT(expires, '%d.%m.%Y'), NULL) as expires, IF(expires,expires<CURDATE(),FALSE) as expired, DATE_FORMAT(created, '%e. %b %Y') as created, public, access_code, CHAR_LENGTH(descr) > 0 AS hasText FROM studiport_view WHERE user_id='$id_esc' ORDER BY name");
		$res->query(
			"SELECT ".
			"  view_id, ".
			"  name, ".
			"  descr, ".
			"  IF(expires, DATE_FORMAT(expires, '%d.%m.%Y'), NULL) as expires, ".
			"  IF(expires,expires<CURDATE(),FALSE) as expired, ".
			"  DATE_FORMAT(created, '%e. %b %Y') as created, ".
			"  public, ".
//			"  access_code, ".
			"  CHAR_LENGTH(descr) > 0 AS hasText ".
			"FROM studiport_view ".
			"WHERE $whereCl ".
			"ORDER BY name");
		$this->views = array();
		while ($res->next_record()) {
			$this->views[$res->Record['view_id']] = $res->Record;
		}

		// TODO possible merge these into the above SQL statement, if possible and faster
		// then get number of files associated to views
		$res->query("SELECT view_id, COUNT(*) as 'numFiles' FROM studiport_view_files WHERE view_id IN (SELECT view_id FROM studiport_view WHERE $whereCl) GROUP BY view_id");
		$this->numFiles = array();
		while ($res->next_record()) {
			$this->views[$res->Record['view_id']]['numFiles'] = $res->Record['numFiles'];
		}

		// then get number of users associated to views
		$res->query("SELECT view_id, COUNT(*) as 'numAccess' FROM studiport_view_access WHERE view_id IN (SELECT view_id FROM studiport_view WHERE $whereCl) GROUP BY view_id");
		$this->numFiles = array();
		while ($res->next_record()) {
			$this->views[$res->Record['view_id']]['numAccess'] = $res->Record['numAccess'];
		}

		// get information about new feedback
		$res->query("SELECT view_id, SUM(viewed='N') as 'numNewFeedback', COUNT(*) as 'numFeedback' FROM studiport_feedback_response INNER JOIN studiport_feedback_question USING (question_id) WHERE view_id IN (SELECT view_id FROM studiport_view WHERE $whereCl) GROUP BY view_id");
		$this->numNewFeedback = array();
		while ($res->next_record()) {
			$this->views[$res->Record['view_id']]['numNewFeedback'] = $res->Record['numNewFeedback'];
			$this->views[$res->Record['view_id']]['numFeedback']    = $res->Record['numFeedback'];
		}
	}
	
	/**
	* @param id file id from studiport_files table
	*/
	public function render(Flexi_TemplateFactory &$factory, $templateFilename, $pluginUrl) {
		parent::render($factory, $templateFilename, $pluginUrl);
		//$template->set_layout('StudIPortLayout.php');
		//$template->set_attribute('path', $this->path);
		$this->template->set_attribute('views', $this->views);
		return $this->template->render();
	}

	public function getNum() {
		return count($this->views);
	}
}
?>
