SET FOREIGN_KEY_CHECKS=0;
SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";


CREATE TABLE IF NOT EXISTS `studiport_file` (
  file_id       int(10) unsigned  NOT NULL  auto_increment,
  int_filename  varchar(255), -- unique filename (internal use)
  filename      varchar(255)      NOT NULL,     -- full filename
  type_id       int(10) unsigned  NOT NULL,  -- foreign-key
  mimetype      varchar(255)      NOT NULL,
  filesize      int(10) unsigned  NOT NULL,
  created       timestamp         NOT NULL  default '0000-00-00 00:00:00',   -- not set automatically, must be set at insert
  edited        timestamp         NOT NULL  default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  title         varchar(255)      NOT NULL,  -- should be original filename if no title is given
  descr_int     text              NULL      default NULL,
  descr_ext     text              NULL      default NULL,
  user_id       char(32)          NOT NULL, -- owner
  PRIMARY KEY  (`file_id`),
  INDEX `user_id` (`user_id`),
  INDEX `type_id` (`type_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 COLLATE latin1_german1_ci;


CREATE TABLE IF NOT EXISTS `studiport_file_assoc` (
  file_id       int(10) unsigned  NOT NULL, -- foreign-key
  comp_id       int(10) unsigned  NOT NULL, -- foreign-key
  exp_id        int(10) unsigned  NOT NULL, -- foreign-key
  PRIMARY KEY  (`file_id`),
  INDEX(`comp_id`, `exp_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE latin1_german1_ci;


CREATE TABLE IF NOT EXISTS `studiport_file_types` (
  type_id       int(10) unsigned  NOT NULL auto_increment,
  name          varchar(50)       NOT NULL, -- readable name
  picture       varchar(255)      NOT NULL  DEFAULT 'filetype-unknown.png', -- file found at <pluginfolder>/pictures
  picture_large varchar(255)      NOT NULL  DEFAULT 'filetype-unknown-large.png', -- file found at <pluginfolder>/pictures
  descr         varchar(255)      NULL      DEFAULT NULL,
  mimefrag      varchar(255)      NULL      DEFAULT NULL,
  PRIMARY KEY  (`type_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 COLLATE latin1_german1_ci;


CREATE TABLE IF NOT EXISTS `studiport_file_mime` (
  type_id       int(10) unsigned  NOT NULL,
  mime_type     varchar(255)      NOT NULL,
  descr         varchar(255)      NULL      default NULL,
  PRIMARY KEY  (`mime_type`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 COLLATE latin1_german1_ci;


CREATE TABLE IF NOT EXISTS `studiport_view` (
  view_id       int(10) unsigned  NOT NULL  auto_increment,
  name          varchar(50)       NOT NULL,
  descr         text,
  user_id       char(32)          NOT NULL,  -- owner
  expires       date              NOT NULL  default '0000-00-00', -- no automaticly set, must be set at insert
  created       timestamp         NOT NULL  default '0000-00-00 00:00:00',   -- not set automatically, must be set at insert
  edited        timestamp         NOT NULL  default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  public        ENUM ('Y', 'N')   NOT NULL  default 'N',
  access_code   char(32)          NOT NULL,
  PRIMARY KEY  (`view_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 COLLATE latin1_german1_ci;


CREATE TABLE IF NOT EXISTS `studiport_view_access` (
  view_id       int(10) unsigned  NOT NULL, -- foreign-key
  user_id       char(32)          NOT NULL, -- user with access
  viewed        enum('Y', 'N')    NOT NULL  DEFAULT 'N',
  accesstime    timestamp         NULL      DEFAULT NULL, -- access time of user
  PRIMARY KEY (`view_id`, `user_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 COLLATE latin1_german1_ci;


CREATE TABLE IF NOT EXISTS `studiport_view_files` (
  view_id       int(10) unsigned  NOT NULL, -- foreign-key
  file_id       int(10) unsigned  NOT NULL, -- foreign-key
  PRIMARY KEY (`view_id`, `file_id`)
) ENGINE=InnoDB  DEFAULT CHARSET=latin1 COLLATE latin1_german1_ci;


CREATE TABLE IF NOT EXISTS `studiport_feedback_question` (
  question_id   int(10) unsigned  NOT NULL  auto_increment, -- primary key
  view_id       int(10) unsigned  NOT NULL, -- foreign-key,
  created       timestamp         NOT NULL  default '0000-00-00 00:00:00',
  edited        timestamp         NOT NULL  default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  expires       date              NOT NULL  default '0000-00-00', 
  text          TEXT              NOT NULL,
  public        enum ('Y', 'N')   NOT NULL  default 'N',
  PRIMARY KEY (`question_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE latin1_german1_ci;


CREATE TABLE IF NOT EXISTS `studiport_feedback_request` (
  question_id   int(10) unsigned  NOT NULL,  -- foreign-key
  user_id       char(32)          NOT NULL,  -- foreign key, user requested to give feedback
  PRIMARY KEY (`question_id`, `user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE latin1_german1_ci;


CREATE TABLE IF NOT EXISTS `studiport_feedback_response` (
  response_id   int(10) unsigned  NOT NULL  auto_increment, -- primary key
  question_id   int(10) unsigned  NOT NULL, -- foreign-key,
  user_id       char(32),                      -- foreign key, user giving feedback
  author        VARCHAR(255),                   -- author in case of external feedback
  created       timestamp         NOT NULL  default '0000-00-00 00:00:00',
  edited        timestamp         NOT NULL  default CURRENT_TIMESTAMP,
  text          TEXT,
  viewed        enum('Y', 'N')    NOT NULL  default 'N',
  PRIMARY KEY (`response_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE latin1_german1_ci;



CREATE TABLE IF NOT EXISTS `studiport_matrix_cell_descr` (
  user_id       char(32)          NOT NULL, -- owner
  comp_id       int(10) unsigned  NOT NULL, -- foreign-key
  exp_id        int(10) unsigned  NOT NULL, -- foreign-key
  text_ext      text              NULL      DEFAULT NULL,
  text_int      text              NULL      DEFAULT NULL,
  created       timestamp         NOT NULL  default '0000-00-00 00:00:00', -- no automatic set, must be set at insert
  edited        timestamp         NOT NULL  default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (`user_id`,`comp_id`,`exp_id`),
  INDEX `comp_id` (`comp_id`),
  INDEX `exp_id` (`exp_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE latin1_german1_ci;


CREATE TABLE IF NOT EXISTS `studiport_matrix_exp` (
  exp_id        int(10) unsigned  NOT NULL auto_increment,
  title         varchar(255)      NOT NULL, -- tableheader
  descr         text              NULL      default NULL,
  pos           tinyint(4) unsigned  NOT NULL  default '0', -- 0 for tableheader, 1..x for normal entry
  PRIMARY KEY  (`exp_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE latin1_german1_ci;


CREATE TABLE IF NOT EXISTS `studiport_matrix_comp` (
  comp_id       int(10) unsigned  NOT NULL auto_increment,
  title         varchar(255)      NOT NULL, -- table"header"
  descr         text              NULL      default NULL,
  pos           tinyint(4) unsigned  NOT NULL default '0', -- 0 for tableheader, 1..x for normal entry
  PRIMARY KEY  (`comp_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE latin1_german1_ci;


CREATE TABLE IF NOT EXISTS `studiport_matrix_exp_hide` (
  exp_id        int(10) unsigned  NOT NULL,
  user_id       char(32)       NOT NULL,
  PRIMARY KEY  (`exp_id`,`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_german1_ci;


CREATE TABLE IF NOT EXISTS `studiport_matrix_comp_hide` (
  comp_id       int(10) unsigned  NOT NULL,
  user_id       char(32)          NOT NULL,
  PRIMARY KEY  (`comp_id`,`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_german1_ci;


ALTER TABLE `studiport_file_mime`
  ADD CONSTRAINT `studiport_file_mime_ibfk_1` FOREIGN KEY (`type_id`) REFERENCES `studiport_file_types` (`type_id`) ON DELETE NO ACTION ON UPDATE NO ACTION;

ALTER TABLE `studiport_file`
  ADD CONSTRAINT `studiport_file_ibfk_1` FOREIGN KEY (`type_id`) REFERENCES `studiport_file_types` (`type_id`) ON DELETE NO ACTION ON UPDATE NO ACTION;

ALTER TABLE `studiport_view_access`
  ADD CONSTRAINT `studiport_view_access_ibfk_1` FOREIGN KEY (`view_id`) REFERENCES `studiport_view` (`view_id`) ON DELETE NO ACTION ON UPDATE NO ACTION;

ALTER TABLE `studiport_view_files`
  ADD CONSTRAINT `studiport_view_files_ibfk_2` FOREIGN KEY (`file_id`) REFERENCES `studiport_file` (`file_id`) ON DELETE NO ACTION ON UPDATE NO ACTION,
  ADD CONSTRAINT `studiport_view_files_ibfk_1` FOREIGN KEY (`view_id`) REFERENCES `studiport_view` (`view_id`) ON DELETE NO ACTION ON UPDATE NO ACTION;

ALTER TABLE `studiport_feedback_question`
  ADD CONSTRAINT `studiport_feedback_question_ibfk_1` FOREIGN KEY (`view_id`) REFERENCES `studiport_view` (`view_id`) ON DELETE NO ACTION ON UPDATE NO ACTION;

ALTER TABLE `studiport_feedback_request`
  ADD CONSTRAINT `studiport_feedback_request_ibfk_1` FOREIGN KEY (`question_id`) REFERENCES `studiport_feedback_question` (`question_id`) ON DELETE NO ACTION ON UPDATE NO ACTION;

ALTER TABLE `studiport_feedback_response`
  ADD CONSTRAINT `studiport_feedback_response_ibfk_1` FOREIGN KEY (`question_id`) REFERENCES `studiport_feedback_question` (`question_id`) ON DELETE NO ACTION ON UPDATE NO ACTION;

ALTER TABLE `studiport_file_assoc`
  ADD CONSTRAINT `studiport_file_assoc_ibfk_1` FOREIGN KEY (`file_id`) REFERENCES `studiport_file` (`file_id`) ON DELETE NO ACTION ON UPDATE NO ACTION,
  ADD CONSTRAINT `studiport_file_assoc_ibfk_2` FOREIGN KEY (`comp_id`) REFERENCES `studiport_matrix_comp` (`comp_id`) ON DELETE NO ACTION ON UPDATE NO ACTION,
  ADD CONSTRAINT `studiport_file_assoc_ibfk_3` FOREIGN KEY (`exp_id`) REFERENCES `studiport_matrix_exp` (`exp_id`) ON DELETE NO ACTION ON UPDATE NO ACTION;

ALTER TABLE `studiport_matrix_cell_descr`
  ADD CONSTRAINT `studiport_matrix_cell_descr_ibfk_2` FOREIGN KEY (`exp_id`) REFERENCES `studiport_matrix_exp` (`exp_id`) ON DELETE NO ACTION ON UPDATE NO ACTION,
  ADD CONSTRAINT `studiport_matrix_cell_descr_ibfk_1` FOREIGN KEY (`comp_id`) REFERENCES `studiport_matrix_comp` (`comp_id`) ON DELETE NO ACTION ON UPDATE NO ACTION;

ALTER TABLE `studiport_matrix_exp_hide`
  ADD CONSTRAINT `studiport_matrix_exp_hide_ibfk_1` FOREIGN KEY (`exp_id`) REFERENCES `studiport_matrix_exp` (`exp_id`) ON DELETE NO ACTION ON UPDATE NO ACTION;

ALTER TABLE `studiport_matrix_comp_hide`
  ADD CONSTRAINT `studiport_matrix_comp_hide_ibfk_1` FOREIGN KEY (`comp_id`) REFERENCES `studiport_matrix_comp` (`comp_id`) ON DELETE NO ACTION ON UPDATE NO ACTION;


SET FOREIGN_KEY_CHECKS=1;
